@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,8 +24,7 @@
 #include <PimCommon/PluginUtil>
 #include "kaddressbook_importexport_export.h"
 
-namespace KAddressBookImportExport
-{
+namespace KAddressBookImportExport {
 class KAddressBookImportExportPlugin;
 class KAddressBookImportExportPrivate;
 class KADDRESSBOOK_IMPORTEXPORT_EXPORT KAddressBookImportExportPluginManager : public QObject
@@ -36,12 +35,12 @@ public:
     ~KAddressBookImportExportPluginManager();
     static KAddressBookImportExportPluginManager *self();
 
-    QVector<KAddressBookImportExportPlugin *> pluginsList() const;
+    Q_REQUIRED_RESULT QVector<KAddressBookImportExportPlugin *> pluginsList() const;
 
-    QVector<PimCommon::PluginUtilData> pluginsDataList() const;
+    Q_REQUIRED_RESULT QVector<PimCommon::PluginUtilData> pluginsDataList() const;
 
-    QString configGroupName() const;
-    QString configPrefixSettingKey() const;
+    Q_REQUIRED_RESULT QString configGroupName() const;
+    Q_REQUIRED_RESULT QString configPrefixSettingKey() const;
     KAddressBookImportExportPlugin *pluginFromIdentifier(const QString &id);
 private:
     KAddressBookImportExportPrivate *const d;
